.. :Analyser:

Analyser
==========

.. currentmodule:: Analyser



.. autosummary::
   :nosignatures:

    Analyser.Analyser
    Analyser.Analyser.__init__
    Analyser.Analyser.plot
    Analyser.FlatAnalyser
    Analyser.FlatAnalyser.__init__
    Analyser.FlatAnalyser.plot
    
	


Analyser Object and Methods
---------------------------


.. automodule:: Analyser

.. _Analyser:

.. autoclass:: Analyser
    :members:

    .. automethod:: __init__


FlatAnalyser Object and Methods
-------------------------------


.. _FlatAnalyser:

.. autoclass:: FlatAnalyser
    :members:

    .. automethod:: __init__

